@@ -1,9 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 # SPDX-License-Identifier: Apache-2.0
-
 import ast
 import logging
 import operator
@@ -16,15 +14,14 @@ from bandit.core import utils as b_utils
 LOG = logging.getLogger(__name__)
 
 
-class BanditNodeVisitor(object):
-    def __init__(self, fname, metaast, testset,
-                 debug, nosec_lines, metrics):
+class BanditNodeVisitor:
+    def __init__(self, fname, metaast, testset, debug, nosec_lines, metrics):
         self.debug = debug
         self.nosec_lines = nosec_lines
         self.seen = 0
         self.scores = {
-            'SEVERITY': [0] * len(constants.RANKING),
-            'CONFIDENCE': [0] * len(constants.RANKING)
+            "SEVERITY": [0] * len(constants.RANKING),
+            "CONFIDENCE": [0] * len(constants.RANKING),
         }
         self.depth = 0
         self.fname = fname
@@ -33,91 +30,93 @@ class BanditNodeVisitor(object):
         self.imports = set()
         self.import_aliases = {}
         self.tester = b_tester.BanditTester(
-            self.testset, self.debug, nosec_lines)
+            self.testset, self.debug, nosec_lines
+        )
 
         # in some cases we can't determine a qualified name
         try:
             self.namespace = b_utils.get_module_qualname_from_path(fname)
         except b_utils.InvalidModulePath:
-            LOG.info('Unable to find qualified name for module: %s',
-                     self.fname)
+            LOG.info(
+                "Unable to find qualified name for module: %s", self.fname
+            )
             self.namespace = ""
-        LOG.debug('Module qualified name: %s', self.namespace)
+        LOG.debug("Module qualified name: %s", self.namespace)
         self.metrics = metrics
 
     def visit_ClassDef(self, node):
-        '''Visitor for AST ClassDef node
+        """Visitor for AST ClassDef node
 
         Add class name to current namespace for all descendants.
         :param node: Node being inspected
         :return: -
-        '''
+        """
         # For all child nodes, add this class name to current namespace
         self.namespace = b_utils.namespace_path_join(self.namespace, node.name)
 
     def visit_FunctionDef(self, node):
-        '''Visitor for AST FunctionDef nodes
+        """Visitor for AST FunctionDef nodes
 
         add relevant information about the node to
         the context for use in tests which inspect function definitions.
         Add the function name to the current namespace for all descendants.
         :param node: The node that is being inspected
         :return: -
-        '''
+        """
 
-        self.context['function'] = node
-        qualname = self.namespace + '.' + b_utils.get_func_name(node)
-        name = qualname.split('.')[-1]
+        self.context["function"] = node
+        qualname = self.namespace + "." + b_utils.get_func_name(node)
+        name = qualname.split(".")[-1]
 
-        self.context['qualname'] = qualname
-        self.context['name'] = name
+        self.context["qualname"] = qualname
+        self.context["name"] = name
 
         # For all child nodes and any tests run, add this function name to
         # current namespace
         self.namespace = b_utils.namespace_path_join(self.namespace, name)
-        self.update_scores(self.tester.run_tests(self.context, 'FunctionDef'))
+        self.update_scores(self.tester.run_tests(self.context, "FunctionDef"))
 
     def visit_Call(self, node):
-        '''Visitor for AST Call nodes
+        """Visitor for AST Call nodes
 
         add relevant information about the node to
         the context for use in tests which inspect function calls.
         :param node: The node that is being inspected
         :return: -
-        '''
+        """
 
-        self.context['call'] = node
+        self.context["call"] = node
         qualname = b_utils.get_call_name(node, self.import_aliases)
-        name = qualname.split('.')[-1]
+        name = qualname.split(".")[-1]
 
-        self.context['qualname'] = qualname
-        self.context['name'] = name
+        self.context["qualname"] = qualname
+        self.context["name"] = name
 
-        self.update_scores(self.tester.run_tests(self.context, 'Call'))
+        self.update_scores(self.tester.run_tests(self.context, "Call"))
 
     def visit_Import(self, node):
-        '''Visitor for AST Import nodes
+        """Visitor for AST Import nodes
 
         add relevant information about node to
         the context for use in tests which inspect imports.
         :param node: The node that is being inspected
         :return: -
-        '''
+        """
         for nodename in node.names:
             if nodename.asname:
                 self.import_aliases[nodename.asname] = nodename.name
             self.imports.add(nodename.name)
-            self.context['module'] = nodename.name
-        self.update_scores(self.tester.run_tests(self.context, 'Import'))
+            self.context["module"] = nodename.name
+        self.update_scores(self.tester.run_tests(self.context, "Import"))
 
     def visit_ImportFrom(self, node):
-        '''Visitor for AST ImportFrom nodes
+        """Visitor for AST ImportFrom nodes
 
         add relevant information about node to
         the context for use in tests which inspect imports.
         :param node: The node that is being inspected
         :return: -
-        '''
+        """
         module = node.module
         if module is None:
             return self.visit_Import(node)
@@ -135,15 +134,16 @@ class BanditNodeVisitor(object):
                 # Even if import is not aliased we need an entry that maps
                 # name to module.name.  For example, with 'from a import b'
                 # b should be aliased to the qualified name a.b
-                self.import_aliases[nodename.name] = (module + '.' +
-                                                      nodename.name)
+                self.import_aliases[nodename.name] = (
+                    module + "." + nodename.name
+                )
             self.imports.add(module + "." + nodename.name)
-            self.context['module'] = module
-            self.context['name'] = nodename.name
-        self.update_scores(self.tester.run_tests(self.context, 'ImportFrom'))
+            self.context["module"] = module
+            self.context["name"] = nodename.name
+        self.update_scores(self.tester.run_tests(self.context, "ImportFrom"))
 
     def visit_Constant(self, node):
-        '''Visitor for AST Constant nodes
+        """Visitor for AST Constant nodes
 
         call the appropriate method for the node type.
         this maintains compatibility with <3.6 and 3.8+
@@ -153,73 +153,76 @@ class BanditNodeVisitor(object):
 
         :param node: The node that is being inspected
         :return: -
-        '''
+        """
         if isinstance(node.value, str):
             self.visit_Str(node)
         elif isinstance(node.value, bytes):
             self.visit_Bytes(node)
 
     def visit_Str(self, node):
-        '''Visitor for AST String nodes
+        """Visitor for AST String nodes
 
         add relevant information about node to
         the context for use in tests which inspect strings.
         :param node: The node that is being inspected
         :return: -
-        '''
-        self.context['str'] = node.s
+        """
+        self.context["str"] = node.s
         if not isinstance(node._bandit_parent, ast.Expr):  # docstring
-            self.context['linerange'] = b_utils.linerange_fix(
+            self.context["linerange"] = b_utils.linerange_fix(
                 node._bandit_parent
             )
-            self.update_scores(self.tester.run_tests(self.context, 'Str'))
+            self.update_scores(self.tester.run_tests(self.context, "Str"))
 
     def visit_Bytes(self, node):
-        '''Visitor for AST Bytes nodes
+        """Visitor for AST Bytes nodes
 
         add relevant information about node to
         the context for use in tests which inspect strings.
         :param node: The node that is being inspected
         :return: -
-        '''
-        self.context['bytes'] = node.s
+        """
+        self.context["bytes"] = node.s
         if not isinstance(node._bandit_parent, ast.Expr):  # docstring
-            self.context['linerange'] = b_utils.linerange_fix(
+            self.context["linerange"] = b_utils.linerange_fix(
                 node._bandit_parent
             )
-            self.update_scores(self.tester.run_tests(self.context, 'Bytes'))
+            self.update_scores(self.tester.run_tests(self.context, "Bytes"))
 
     def pre_visit(self, node):
         self.context = {}
-        self.context['imports'] = self.imports
-        self.context['import_aliases'] = self.import_aliases
+        self.context["imports"] = self.imports
+        self.context["import_aliases"] = self.import_aliases
 
         if self.debug:
             LOG.debug(ast.dump(node))
-            self.metaast.add_node(node, '', self.depth)
+            self.metaast.add_node(node, "", self.depth)
 
-        if hasattr(node, 'lineno'):
-            self.context['lineno'] = node.lineno
+        if hasattr(node, "lineno"):
+            self.context["lineno"] = node.lineno
 
             if node.lineno in self.nosec_lines:
                 LOG.debug("skipped, nosec")
                 self.metrics.note_nosec()
                 return False
+        if hasattr(node, "col_offset"):
+            self.context["col_offset"] = node.col_offset
 
-        self.context['node'] = node
-        self.context['linerange'] = b_utils.linerange_fix(node)
-        self.context['filename'] = self.fname
+        self.context["node"] = node
+        self.context["linerange"] = b_utils.linerange_fix(node)
+        self.context["filename"] = self.fname
 
         self.seen += 1
-        LOG.debug("entering: %s %s [%s]", hex(id(node)), type(node),
-                  self.depth)
+        LOG.debug(
+            "entering: %s %s [%s]", hex(id(node)), type(node), self.depth
+        )
         self.depth += 1
         LOG.debug(self.context)
         return True
 
     def visit(self, node):
         name = node.__class__.__name__
-        method = 'visit_' + name
+        method = "visit_" + name
         visitor = getattr(self, method, None)
         if visitor is not None:
             if self.debug:
@@ -264,26 +267,26 @@ class BanditNodeVisitor(object):
                     self.post_visit(value)
 
     def update_scores(self, scores):
-        '''Score updater
+        """Score updater
 
         Since we moved from a single score value to a map of scores per
         severity, this is needed to update the stored list.
         :param score: The score list to update our scores with
-        '''
+        """
         # we'll end up with something like:
         # SEVERITY: {0, 0, 0, 10}  where 10 is weighted by finding and level
         for score_type in self.scores:
-            self.scores[score_type] = list(map(
-                operator.add, self.scores[score_type], scores[score_type]
-            ))
+            self.scores[score_type] = list(
+                map(operator.add, self.scores[score_type], scores[score_type])
+            )
 
     def process(self, data):
-        '''Main process loop
+        """Main process loop
 
         Build and process the AST
         :param lines: lines code to process
         :return score: the aggregated score for the current file
-        '''
+        """
         f_ast = ast.parse(data)
         self.generic_visit(f_ast)
         return self.scores
