@@ -1,8 +1,6 @@
 # Copyright (c) 2015 Hewlett Packard Enterprise
-# -*- coding:utf-8 -*-
 #
 # SPDX-License-Identifier: Apache-2.0
-
 r"""
 ================
 Screen formatter
@@ -27,9 +25,6 @@ This formatter outputs the issues as color coded text to screen.
 .. versionadded:: 0.9.0
 
 """
-
-from __future__ import print_function
-
 import datetime
 import logging
 import sys
@@ -38,7 +33,7 @@ from bandit.core import constants
 from bandit.core import docs_utils
 from bandit.core import test_properties
 
-IS_WIN_PLATFORM = sys.platform.startswith('win32')
+IS_WIN_PLATFORM = sys.platform.startswith("win32")
 COLORAMA = False
 
 # This fixes terminal colors not displaying properly on Windows systems.
@@ -56,28 +51,31 @@ if IS_WIN_PLATFORM:
 LOG = logging.getLogger(__name__)
 
 COLOR = {
-    'DEFAULT': '\033[0m',
-    'HEADER': '\033[95m',
-    'LOW': '\033[94m',
-    'MEDIUM': '\033[93m',
-    'HIGH': '\033[91m',
+    "DEFAULT": "\033[0m",
+    "HEADER": "\033[95m",
+    "LOW": "\033[94m",
+    "MEDIUM": "\033[93m",
+    "HIGH": "\033[91m",
 }
 
 
 def header(text, *args):
-    return u'%s%s%s' % (COLOR['HEADER'], (text % args), COLOR['DEFAULT'])
+    return "{}{}{}".format(COLOR["HEADER"], (text % args), COLOR["DEFAULT"])
 
 
 def get_verbose_details(manager):
     bits = []
-    bits.append(header(u'Files in scope (%i):', len(manager.files_list)))
-    tpl = u"\t%s (score: {SEVERITY: %i, CONFIDENCE: %i})"
-    bits.extend([tpl % (item, sum(score['SEVERITY']), sum(score['CONFIDENCE']))
-                 for (item, score)
-                 in zip(manager.files_list, manager.scores)])
-    bits.append(header(u'Files excluded (%i):', len(manager.excluded_files)))
-    bits.extend([u"\t%s" % fname for fname in manager.excluded_files])
-    return '\n'.join([str(bit) for bit in bits])
+    bits.append(header("Files in scope (%i):", len(manager.files_list)))
+    tpl = "\t%s (score: {SEVERITY: %i, CONFIDENCE: %i})"
+    bits.extend(
+        [
+            tpl % (item, sum(score["SEVERITY"]), sum(score["CONFIDENCE"]))
+            for (item, score) in zip(manager.files_list, manager.scores)
+        ]
+    )
+    bits.append(header("Files excluded (%i):", len(manager.excluded_files)))
+    bits.extend(["\t%s" % fname for fname in manager.excluded_files])
+    return "\n".join([str(bit) for bit in bits])
 
 
 def get_metrics(manager):
@@ -86,44 +84,68 @@ def get_metrics(manager):
     for (criteria, _) in constants.CRITERIA:
         bits.append("\tTotal issues (by %s):" % (criteria.lower()))
         for rank in constants.RANKING:
-            bits.append("\t\t%s: %s" % (
-                rank.capitalize(),
-                manager.metrics.data['_totals']['%s.%s' % (criteria, rank)]))
-    return '\n'.join([str(bit) for bit in bits])
+            bits.append(
+                "\t\t%s: %s"
+                % (
+                    rank.capitalize(),
+                    manager.metrics.data["_totals"][f"{criteria}.{rank}"],
+                )
+            )
+    return "\n".join([str(bit) for bit in bits])
 
 
-def _output_issue_str(issue, indent, show_lineno=True, show_code=True,
-                      lines=-1):
+def _output_issue_str(
+    issue, indent, show_lineno=True, show_code=True, lines=-1
+):
     # returns a list of lines that should be added to the existing lines list
     bits = []
-    bits.append("%s%s>> Issue: [%s:%s] %s" % (
-        indent, COLOR[issue.severity], issue.test_id, issue.test, issue.text))
+    bits.append(
+        "%s%s>> Issue: [%s:%s] %s"
+        % (
+            indent,
+            COLOR[issue.severity],
+            issue.test_id,
+            issue.test,
+            issue.text,
+        )
+    )
 
-    bits.append("%s   Severity: %s   Confidence: %s" % (
-        indent, issue.severity.capitalize(), issue.confidence.capitalize()))
+    bits.append(
+        "%s   Severity: %s   Confidence: %s"
+        % (indent, issue.severity.capitalize(), issue.confidence.capitalize())
+    )
 
-    bits.append("%s   Location: %s:%s" % (
-        indent, issue.fname,
-        issue.lineno if show_lineno else ""))
+    bits.append(
+        "%s   Location: %s:%s:%s"
+        % (
+            indent,
+            issue.fname,
+            issue.lineno if show_lineno else "",
+            issue.col_offset if show_lineno else "",
+        )
+    )
 
-    bits.append("%s   More Info: %s%s" % (
-        indent, docs_utils.get_url(issue.test_id), COLOR['DEFAULT']))
+    bits.append(
+        "%s   More Info: %s%s"
+        % (indent, docs_utils.get_url(issue.test_id), COLOR["DEFAULT"])
+    )
 
     if show_code:
-        bits.extend([indent + line for line in
-                     issue.get_code(lines, True).split('\n')])
+        bits.extend(
+            [indent + line for line in issue.get_code(lines, True).split("\n")]
+        )
 
-    return '\n'.join([bit for bit in bits])
+    return "\n".join([bit for bit in bits])
 
 
 def get_results(manager, sev_level, conf_level, lines):
     bits = []
     issues = manager.get_issue_list(sev_level, conf_level)
     baseline = not isinstance(issues, list)
-    candidate_indent = ' ' * 10
+    candidate_indent = " " * 10
 
     if not len(issues):
-        return u"\tNo issues identified."
+        return "\tNo issues identified."
 
     for issue in issues:
         # if not a baseline or only one candidate we know the issue
@@ -132,24 +154,26 @@ def get_results(manager, sev_level, conf_level, lines):
 
         # otherwise show the finding and the candidates
         else:
-            bits.append(_output_issue_str(issue, "",
-                                          show_lineno=False,
-                                          show_code=False))
+            bits.append(
+                _output_issue_str(
+                    issue, "", show_lineno=False, show_code=False
+                )
+            )
 
-            bits.append(u'\n-- Candidate Issues --')
+            bits.append("\n-- Candidate Issues --")
             for candidate in issues[issue]:
-                bits.append(_output_issue_str(candidate,
-                                              candidate_indent,
-                                              lines=lines))
-                bits.append('\n')
-        bits.append(u'-' * 50)
+                bits.append(
+                    _output_issue_str(candidate, candidate_indent, lines=lines)
+                )
+                bits.append("\n")
+        bits.append("-" * 50)
 
-    return '\n'.join([bit for bit in bits])
+    return "\n".join([bit for bit in bits])
 
 
 def do_print(bits):
     # needed so we can mock this stuff
-    print('\n'.join([bit for bit in bits]))
+    print("\n".join([bit for bit in bits]))
 
 
 @test_properties.accepts_baseline
@@ -178,11 +202,15 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
         bits.append(header("\nTest results:"))
         bits.append(get_results(manager, sev_level, conf_level, lines))
         bits.append(header("\nCode scanned:"))
-        bits.append('\tTotal lines of code: %i' %
-                    (manager.metrics.data['_totals']['loc']))
+        bits.append(
+            "\tTotal lines of code: %i"
+            % (manager.metrics.data["_totals"]["loc"])
+        )
 
-        bits.append('\tTotal lines skipped (#nosec): %i' %
-                    (manager.metrics.data['_totals']['nosec']))
+        bits.append(
+            "\tTotal lines skipped (#nosec): %i"
+            % (manager.metrics.data["_totals"]["nosec"])
+        )
 
         bits.append(get_metrics(manager))
         skipped = manager.get_skipped()
@@ -191,8 +219,11 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
         do_print(bits)
 
     if fileobj.name != sys.stdout.name:
-        LOG.info("Screen formatter output was not written to file: %s, "
-                 "consider '-f txt'", fileobj.name)
+        LOG.info(
+            "Screen formatter output was not written to file: %s, "
+            "consider '-f txt'",
+            fileobj.name,
+        )
 
     if IS_WIN_PLATFORM and COLORAMA:
         colorama.deinit()
