@@ -1,9 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 # SPDX-License-Identifier: Apache-2.0
-
 r"""
 ==============================
 B102: Test for the use of exec
@@ -18,7 +16,7 @@ Python docs succinctly describe why the use of `exec` is risky.
 
     >> Issue: Use of exec detected.
        Severity: Medium   Confidence: High
-       Location: ./examples/exec-py2.py:2
+       Location: ./examples/exec.py:2
     1 exec("do evil")
     2 exec "do evil"
 
@@ -31,9 +29,6 @@ Python docs succinctly describe why the use of `exec` is risky.
 
 .. versionadded:: 0.9.0
 """
-
-import six
-
 import bandit
 from bandit.core import test_properties as test
 
@@ -42,18 +37,12 @@ def exec_issue():
     return bandit.Issue(
         severity=bandit.MEDIUM,
         confidence=bandit.HIGH,
-        text="Use of exec detected."
+        text="Use of exec detected.",
     )
 
 
-if six.PY2:
-    @test.checks('Exec')
-    @test.test_id('B102')
-    def exec_used(context):
+@test.checks("Call")
+@test.test_id("B102")
+def exec_used(context):
+    if context.call_function_name_qual == "exec":
         return exec_issue()
-else:
-    @test.checks('Call')
-    @test.test_id('B102')
-    def exec_used(context):
-        if context.call_function_name_qual == 'exec':
-            return exec_issue()
