@@ -1,9 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 # SPDX-License-Identifier: Apache-2.0
-
 r"""
 ========================================
 B104: Test for binding to all interfaces
@@ -32,17 +30,16 @@ binding to all network interfaces.
 .. versionadded:: 0.9.0
 
 """
-
 import bandit
 from bandit.core import test_properties as test
 
 
-@test.checks('Str')
-@test.test_id('B104')
+@test.checks("Str")
+@test.test_id("B104")
 def hardcoded_bind_all_interfaces(context):
-    if context.string_val == '0.0.0.0':
+    if context.string_val == "0.0.0.0":
         return bandit.Issue(
             severity=bandit.MEDIUM,
             confidence=bandit.MEDIUM,
-            text="Possible binding to all interfaces."
+            text="Possible binding to all interfaces.",
         )
