@@ -1,19 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
-
+# SPDX-License-Identifier: Apache-2.0
 r"""
 ===================================================
 B108: Test for insecure usage of tmp file/directory
@@ -54,33 +42,32 @@ issue.
 
 .. seealso::
 
- - https://security.openstack.org/guidelines/dg_using-temporary-files-securely.html  # noqa
+ - https://security.openstack.org/guidelines/dg_using-temporary-files-securely.html
 
 .. versionadded:: 0.9.0
 
-"""
-
+"""  # noqa: E501
 import bandit
 from bandit.core import test_properties as test
 
 
 def gen_config(name):
-    if name == 'hardcoded_tmp_directory':
-        return {'tmp_dirs': ['/tmp', '/var/tmp', '/dev/shm']}
+    if name == "hardcoded_tmp_directory":
+        return {"tmp_dirs": ["/tmp", "/var/tmp", "/dev/shm"]}
 
 
 @test.takes_config
-@test.checks('Str')
-@test.test_id('B108')
+@test.checks("Str")
+@test.test_id("B108")
 def hardcoded_tmp_directory(context, config):
-    if config is not None and 'tmp_dirs' in config:
-        tmp_dirs = config['tmp_dirs']
+    if config is not None and "tmp_dirs" in config:
+        tmp_dirs = config["tmp_dirs"]
     else:
-        tmp_dirs = ['/tmp', '/var/tmp', '/dev/shm']
+        tmp_dirs = ["/tmp", "/var/tmp", "/dev/shm"]
 
     if any(context.string_val.startswith(s) for s in tmp_dirs):
         return bandit.Issue(
             severity=bandit.MEDIUM,
             confidence=bandit.MEDIUM,
-            text="Probable insecure usage of temp file/directory."
+            text="Probable insecure usage of temp file/directory.",
         )
