@@ -1,9 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 # SPDX-License-Identifier: Apache-2.0
-
 r"""
 =========================================
 B110: Test for a pass in the except block
@@ -69,7 +67,6 @@ would not generate a warning if the configuration option
 .. versionadded:: 0.13.0
 
 """
-
 import ast
 
 import bandit
@@ -77,24 +74,26 @@ from bandit.core import test_properties as test
 
 
 def gen_config(name):
-    if name == 'try_except_pass':
-        return {'check_typed_exception': False}
+    if name == "try_except_pass":
+        return {"check_typed_exception": False}
 
 
 @test.takes_config
-@test.checks('ExceptHandler')
-@test.test_id('B110')
+@test.checks("ExceptHandler")
+@test.test_id("B110")
 def try_except_pass(context, config):
     node = context.node
     if len(node.body) == 1:
-        if (not config['check_typed_exception'] and
-                node.type is not None and
-                getattr(node.type, 'id', None) != 'Exception'):
+        if (
+            not config["check_typed_exception"]
+            and node.type is not None
+            and getattr(node.type, "id", None) != "Exception"
+        ):
             return
 
         if isinstance(node.body[0], ast.Pass):
             return bandit.Issue(
                 severity=bandit.LOW,
                 confidence=bandit.HIGH,
-                text=("Try, Except, Pass detected.")
+                text=("Try, Except, Pass detected."),
             )
